@@ -18,26 +18,23 @@
  */
 package edu.berkeley.boinc.client;
 
+import android.Manifest.permission;
 import android.content.Context;
 import android.content.Intent;
 import android.content.IntentFilter;
+import android.content.pm.PackageManager;
 import android.net.ConnectivityManager;
 import android.net.Network;
 import android.net.NetworkCapabilities;
-import android.net.NetworkInfo;
 import android.os.BatteryManager;
 import android.os.Build;
 import android.telephony.TelephonyManager;
-import android.util.Log;
-
-import androidx.annotation.RequiresApi;
+import androidx.core.app.ActivityCompat;
 import androidx.core.content.ContextCompat;
-
-import javax.inject.Inject;
-import javax.inject.Singleton;
-
 import edu.berkeley.boinc.rpc.DeviceStatusData;
 import edu.berkeley.boinc.utils.Logging;
+import javax.inject.Inject;
+import javax.inject.Singleton;
 
 @Singleton
 public class DeviceStatus {
@@ -76,7 +73,8 @@ public class DeviceStatus {
 
         connManager = ContextCompat.getSystemService(context, ConnectivityManager.class);
         telManager = ContextCompat.getSystemService(context, TelephonyManager.class);
-        batteryStatus = context.registerReceiver(null, new IntentFilter(Intent.ACTION_BATTERY_CHANGED));
+        batteryStatus =
+                context.registerReceiver(null, new IntentFilter(Intent.ACTION_BATTERY_CHANGED));
     }
 
     /**
@@ -97,11 +95,13 @@ public class DeviceStatus {
         change |= determineUserActive();
 
         if(change) {
-            Log.d(Logging.TAG,
-                  "change: " + " - stationary device: " + stationaryDeviceMode + " ; ac: " +
-                  status.isOnACPower() + " ; level: " + status.getBatteryChargePct() +
-                  " ; temperature: " + status.getBatteryTemperatureCelsius() + " ; wifi: " +
-                  status.isWiFiOnline() + " ; user active: " + status.isUserActive());
+            Logging.logDebug(Logging.Category.DEVICE,
+                             "change: " + " - stationary device: " + stationaryDeviceMode +
+                             " ; ac: " +
+                             status.isOnACPower() + " ; level: " + status.getBatteryChargePct() +
+                             " ; temperature: " + status.getBatteryTemperatureCelsius() +
+                             " ; wifi: " +
+                             status.isWiFiOnline() + " ; user active: " + status.isUserActive());
         }
 
         return status;
@@ -109,7 +109,7 @@ public class DeviceStatus {
 
     /**
      * Returns latest device status, without updating it.
-     * If you need a up-to-date status, call udpate() instead.
+     * If you need a up-to-date status, call update() instead.
      *
      * @return DeviceStatusData, wrapper for device status, contains data retrieved upon last update. Might be in initial state, if no update has successfully finished.
      */
@@ -138,7 +138,19 @@ public class DeviceStatus {
      */
     private boolean determineUserActive() {
         boolean newUserActive;
-        int telStatus = telManager.getCallState();
+        int telStatus;
+        if(Build.VERSION.SDK_INT >= Build.VERSION_CODES.S) {
+            if(ActivityCompat.checkSelfPermission(context, permission.READ_PHONE_STATE) ==
+               PackageManager.PERMISSION_GRANTED) {
+                telStatus = telManager.getCallStateForSubscription();
+            } else {
+                telStatus = TelephonyManager.CALL_STATE_IDLE;
+            }
+        } else {
+            @SuppressWarnings( "deprecation" )
+            int telStatus_ = telManager.getCallState();
+            telStatus = telStatus_;
+        }
 
         if(telStatus != TelephonyManager.CALL_STATE_IDLE) {
             newUserActive = true;
@@ -162,27 +174,14 @@ public class DeviceStatus {
      */
     private boolean determineNetworkStatus() {
         boolean change = false;
-        final boolean isWiFiOrEthernet;
-
-        if(Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
-            isWiFiOrEthernet = isNetworkTypeWiFiOrEthernetOnAPI23AndHigher();
-        }
-        else {
-            int networkType = -1;
-            final NetworkInfo activeNetwork = connManager.getActiveNetworkInfo();
-            if(activeNetwork != null) {
-                networkType = activeNetwork.getType();
-            }
-            isWiFiOrEthernet = networkType == ConnectivityManager.TYPE_WIFI ||
-                               networkType == ConnectivityManager.TYPE_ETHERNET;
-        }
+        final boolean isWiFiOrEthernet = isNetworkTypeWiFiOrEthernet();
 
         if(isWiFiOrEthernet) {
             // WiFi or ethernet is online
             if(!status.isWiFiOnline()) {
                 change = true; // if different from before, set flag
 
-                Log.d(Logging.TAG, "Unlimited Internet connection - WiFi or ethernet - found");
+                Logging.logDebug(Logging.Category.DEVICE, "Unlimited Internet connection - WiFi or ethernet - found");
             }
             status.setWiFiOnline(true);
         }
@@ -197,20 +196,31 @@ public class DeviceStatus {
         return change;
     }
 
-    @RequiresApi(api = Build.VERSION_CODES.M)
-    private boolean isNetworkTypeWiFiOrEthernetOnAPI23AndHigher() {
-        final Network network = connManager.getActiveNetwork();
-
-        if (network != null) {
-            final NetworkCapabilities networkCapabilities = connManager
-                    .getNetworkCapabilities(network);
-            if (networkCapabilities != null) {
-                return networkCapabilities.hasTransport(NetworkCapabilities.TRANSPORT_WIFI) ||
-                       networkCapabilities.hasTransport(NetworkCapabilities.TRANSPORT_ETHERNET);
+    private boolean isNetworkTypeWiFiOrEthernet() {
+        if(Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
+            final Network network = connManager.getActiveNetwork();
+            if (network != null) {
+                final NetworkCapabilities networkCapabilities = connManager
+                        .getNetworkCapabilities(network);
+                if (networkCapabilities != null) {
+                    return networkCapabilities.hasTransport(NetworkCapabilities.TRANSPORT_WIFI) ||
+                           networkCapabilities.hasTransport(NetworkCapabilities.TRANSPORT_ETHERNET);
+                }
             }
+            return false;
+        } else {
+            @SuppressWarnings( "deprecation" )
+            final android.net.NetworkInfo activeNetwork = connManager.getActiveNetworkInfo();
+            if(activeNetwork == null) {
+                return false;
+            }
+            @SuppressWarnings( "deprecation" )
+            final int networkType = activeNetwork.getType();
+            @SuppressWarnings( "deprecation" )
+            final boolean result = networkType == ConnectivityManager.TYPE_WIFI ||
+                             networkType == ConnectivityManager.TYPE_ETHERNET;
+            return result;
         }
-
-        return false;
     }
 
     /**
@@ -233,7 +243,7 @@ public class DeviceStatus {
                 if(!stationaryDeviceMode) { // should not change during run-time. just triggered on initial read
                     change = true;
 
-                    Log.w(Logging.TAG, "No battery found and stationary device mode enabled in preferences -> skip battery status parsing");
+                    Logging.logInfo(Logging.Category.DEVICE, "No battery found and stationary device mode enabled in preferences -> skip battery status parsing");
                 }
                 stationaryDeviceMode = true;
                 setAttributesForStationaryDevice();
