@@ -18,7 +18,6 @@
  */
 package edu.berkeley.boinc.rpc
 
-import android.util.Log
 import android.util.Xml
 import edu.berkeley.boinc.utils.Logging
 import org.xml.sax.Attributes
@@ -52,7 +51,7 @@ class AcctMgrRPCReplyParser : BaseParser() {
                 }
             }
         } catch (e: Exception) {
-            Log.e(Logging.TAG, "AcctMgrRPCReplyParser.endElement error: ", e)
+            Logging.logException(Logging.Category.XML, "AcctMgrRPCReplyParser.endElement error: ", e)
         }
         mElementStarted = false
     }
@@ -67,8 +66,8 @@ class AcctMgrRPCReplyParser : BaseParser() {
                 Xml.parse(rpcResult.replace("<success/>", "<success>1</success>"), parser)
                 parser.accountMgrRPCReply
             } catch (e: SAXException) {
-                Log.e(Logging.TAG, "AcctMgrRPCReplyParser: malformed XML ", e)
-                Log.d(Logging.TAG, "AcctMgrRPCReplyParser: $rpcResult")
+                Logging.logException(Logging.Category.RPC, "AcctMgrRPCReplyParser: malformed XML ", e)
+                Logging.logDebug(Logging.Category.XML, "AcctMgrRPCReplyParser: $rpcResult")
 
                 null
             }
