@@ -15,7 +15,6 @@ fi
 
 ci=""
 component=""
-build_with_vcpkg=""
 
 while [ $# -gt 0 ]; do
     key="$1"
@@ -27,9 +26,6 @@ while [ $# -gt 0 ]; do
         component=$2
         shift
         ;;
-        --with-vcpkg)
-        build_with_vcpkg="$key"
-        ;;
         *)
         echo "unrecognized option $key"
         ;;
@@ -46,10 +42,10 @@ cd android
 
 rm -rf /tmp/vcpkg_updated
 
-./buildAndroidBOINC-CI.sh --cache_dir "$ANDROID_TC" --build_dir "$BUILD_DIR" --silent $ci --component $component $build_with_vcpkg --arch armv6
-./buildAndroidBOINC-CI.sh --cache_dir "$ANDROID_TC" --build_dir "$BUILD_DIR" --silent $ci --component $component $build_with_vcpkg --arch arm
-./buildAndroidBOINC-CI.sh --cache_dir "$ANDROID_TC" --build_dir "$BUILD_DIR" --silent $ci --component $component $build_with_vcpkg --arch arm64
-./buildAndroidBOINC-CI.sh --cache_dir "$ANDROID_TC" --build_dir "$BUILD_DIR" --silent $ci --component $component $build_with_vcpkg --arch x86
-./buildAndroidBOINC-CI.sh --cache_dir "$ANDROID_TC" --build_dir "$BUILD_DIR" --silent $ci --component $component $build_with_vcpkg --arch x86_64
+./buildAndroidBOINC-CI.sh --cache_dir "$ANDROID_TC" --build_dir "$BUILD_DIR" --silent $ci --component $component --arch armv6
+./buildAndroidBOINC-CI.sh --cache_dir "$ANDROID_TC" --build_dir "$BUILD_DIR" --silent $ci --component $component --arch arm
+./buildAndroidBOINC-CI.sh --cache_dir "$ANDROID_TC" --build_dir "$BUILD_DIR" --silent $ci --component $component --arch arm64
+./buildAndroidBOINC-CI.sh --cache_dir "$ANDROID_TC" --build_dir "$BUILD_DIR" --silent $ci --component $component --arch x86
+./buildAndroidBOINC-CI.sh --cache_dir "$ANDROID_TC" --build_dir "$BUILD_DIR" --silent $ci --component $component --arch x86_64
 
 cd ..
