@@ -95,7 +95,7 @@ struct PROC_RESOURCES {
     COPROCS pr_coprocs;
 
     void init() {
-        ncpus = gstate.ncpus;
+        ncpus = gstate.n_usable_cpus;
         ncpus_used_st = 0;
         ncpus_used_mt = 0;
         pr_coprocs.clone(coprocs, false);
@@ -204,7 +204,7 @@ struct PROC_RESOURCES {
         if (log_flags.cpu_sched_debug) {
             msg_printf(rp->project, MSG_INFO,
                 "[cpu_sched_debug] add to run list: %s (%s, %s) (prio %f)",
-                rp->name, 
+                rp->name,
                 rsc_name_long(rt),
                 is_edf?"EDF":"FIFO",
                 rp->project->sched_priority
@@ -269,6 +269,7 @@ bool gpus_usable = true;
 //
 bool check_coprocs_usable() {
 #ifdef _WIN32
+    if (cc_config.no_rdp_check) return false;
     unsigned int i;
     bool new_usable = !is_remote_desktop();
     if (gpus_usable) {
@@ -567,7 +568,7 @@ void CLIENT_STATE::reset_rec_accounting() {
 //
 static void update_rec() {
     double f = gstate.host_info.p_fpops;
-    double on_frac = gstate.global_prefs.cpu_usage_limit / 100;
+    double on_frac = gstate.current_cpu_usage_limit() / 100;
 
     for (unsigned int i=0; i<gstate.projects.size(); i++) {
         PROJECT* p = gstate.projects[i];
@@ -628,7 +629,7 @@ double total_peak_flops() {
     static double tpf;
     if (first) {
         first = false;
-        tpf = gstate.host_info.p_fpops * gstate.ncpus;
+        tpf = gstate.host_info.p_fpops * gstate.n_usable_cpus;
         for (int i=1; i<coprocs.n_rsc; i++) {
             COPROC& cp = coprocs.coprocs[i];
             tpf += rsc_work_fetch[i].relative_speed * gstate.host_info.p_fpops * cp.count;
@@ -780,6 +781,11 @@ bool CLIENT_STATE::schedule_cpus() {
     //
     adjust_rec();
 
+    // this may run tasks that are currently throttled.
+    // Clear flag so that we throttle them again if needed
+    //
+    tasks_throttled = false;
+
     make_run_list(run_list);
     return enforce_run_list(run_list);
 }
@@ -1013,7 +1019,7 @@ static void promote_multi_thread_jobs(vector<RESULT*>& runnable_jobs) {
     vector<RESULT*>::iterator cur = runnable_jobs.begin();
     while(1) {
         if (cur == runnable_jobs.end()) break;
-        if (cpus_used >= gstate.ncpus) break;
+        if (cpus_used >= gstate.n_usable_cpus) break;
         RESULT* rp = *cur;
         if (rp->rr_sim_misses_deadline) break;
         double nc = rp->avp->avg_ncpus;
@@ -1081,11 +1087,14 @@ static inline bool more_important(RESULT* r0, RESULT* r1) {
 }
 
 static void print_job_list(vector<RESULT*>& jobs) {
+    char buf[256];
     for (unsigned int i=0; i<jobs.size(); i++) {
         RESULT* rp = jobs[i];
+        rp->rsc_string(buf, 256);
         msg_printf(rp->project, MSG_INFO,
-            "[cpu_sched_debug] %d: %s (MD: %s; UTS: %s)",
+            "[cpu_sched_debug] %d: %s (%s; MD: %s; UTS: %s)",
             i, rp->name,
+            buf,
             rp->edf_scheduled?"yes":"no",
             rp->unfinished_time_slice?"yes":"no"
         );
@@ -1116,18 +1125,21 @@ void CLIENT_STATE::append_unfinished_time_slice(vector<RESULT*> &run_list) {
 
 // Enforce the CPU schedule.
 // Inputs:
-//   ordered_scheduled_results
-//      List of tasks that should (ideally) run, set by schedule_cpus().
-//      Most important tasks (e.g. early deadline) are first.
-// The set of tasks that actually run may be different:
-// - if a task hasn't checkpointed recently we avoid preempting it
-// - we don't run tasks that would exceed working-set limits
-// Details:
-//   Initially, each task's scheduler_state is PREEMPTED or SCHEDULED
-//     depending on whether or not it is running.
-//     This function sets each task's next_scheduler_state,
-//     and at the end it starts/resumes and preempts tasks
-//     based on scheduler_state and next_scheduler_state.
+//   run_list: list of runnable jobs, ordered by decreasing project priority
+//      (created by make_run_list())
+//      Doesn't include all jobs, but enough to fill CPUs even in MT scenarios.
+//
+// - append running jobs that haven't finished their time slice
+// - order the list by "important" (which includes various factor)
+// - then scan the list and run jobs
+//      - until we've used all resources
+//      - skip jobs that would exceed mem limits
+//
+// Initially, each task's scheduler_state is PREEMPTED or SCHEDULED
+// depending on whether or not it is running.
+// This function sets each task's next_scheduler_state,
+// and at the end it starts/resumes and preempts tasks
+// based on scheduler_state and next_scheduler_state.
 //
 bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
     unsigned int i;
@@ -1169,11 +1181,11 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
         rp->unfinished_time_slice = false;
     }
 
-    // append running jobs not done with time slice to the to-run list
+    // add running jobs not done with time slice to the run list
     //
     append_unfinished_time_slice(run_list);
 
-    // sort to-run list by decreasing importance
+    // sort run list by decreasing importance
     //
     std::sort(
         run_list.begin(),
@@ -1201,7 +1213,6 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
     }
 
     // schedule non-CPU-intensive tasks,
-    // and look for backed-off GPU jobs
     //
     for (i=0; i<results.size(); i++) {
         RESULT* rp = results[i];
@@ -1227,10 +1238,8 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
     // and prune those that can't be assigned
     //
     assign_coprocs(run_list);
-    bool scheduled_mt = false;
 
-    // prune jobs that don't fit in RAM or that exceed CPU usage limits.
-    // Mark the rest as SCHEDULED
+    // scan the run list
     //
     for (i=0; i<run_list.size(); i++) {
         RESULT* rp = run_list[i];
@@ -1247,13 +1256,12 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
 
         atp = lookup_active_task_by_result(rp);
 
-        // if we're already using all the CPUs,
-        // don't allow additional CPU jobs;
+        // if we're already using all the CPUs, don't allow additional CPU jobs;
         // allow coproc jobs if the resulting CPU load is at most ncpus+1
         //
-        if (ncpus_used >= ncpus) {
+        if (ncpus_used >= n_usable_cpus) {
             if (rp->uses_coprocs()) {
-                if (ncpus_used + rp->avp->avg_ncpus > ncpus+1) {
+                if (ncpus_used + rp->avp->avg_ncpus > n_usable_cpus+1) {
                     if (log_flags.cpu_sched_debug) {
                         msg_printf(rp->project, MSG_INFO,
                             "[cpu_sched_debug] skipping GPU job %s; CPU committed",
@@ -1266,7 +1274,7 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
                 if (log_flags.cpu_sched_debug) {
                     msg_printf(rp->project, MSG_INFO,
                         "[cpu_sched_debug] all CPUs used (%.2f >= %d), skipping %s",
-                        ncpus_used, ncpus,
+                        ncpus_used, n_usable_cpus,
                         rp->name
                     );
                 }
@@ -1274,23 +1282,16 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
             }
         }
 
-#if 0
-        // Don't overcommit CPUs by > 1 if a MT job is scheduled.
-        // Skip this check for coproc jobs.
-        //
-        if (!rp->uses_coprocs()
-            && (scheduled_mt || (rp->avp->avg_ncpus > 1))
-            && (ncpus_used + rp->avp->avg_ncpus > ncpus + 1)
-        ) {
-            if (log_flags.cpu_sched_debug) {
-                msg_printf(rp->project, MSG_INFO,
-                    "[cpu_sched_debug] avoid MT overcommit: skipping %s",
-                    rp->name
-                );
-            }
-            continue;
-        }
-#endif
+        // There's a possibility that this job is MT
+        // and would overcommit the CPUs by > 1.
+        // Options are:
+        // 1) run it anyway, and overcommit the CPUs
+        // 2) don't run it.
+        //      This can result in starvation.
+        // 3) don't run it if there are additional 1-CPU jobs.
+        //      The problem here is that we may never run the MT job
+        //      until it reaches deadline pressure.
+        // So we'll go with 1).
 
         // skip jobs whose working set is too large to fit in available RAM
         //
@@ -1310,22 +1311,23 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
             }
             if (log_flags.cpu_sched_debug || log_flags.mem_usage_debug) {
                 msg_printf(rp->project, MSG_INFO,
-                    "[cpu_sched_debug] enforce: task %s can't run, too big %.2fMB > %.2fMB",
+                    "[cpu_sched_debug] can't run %s: WS too big %.2fMB > %.2fMB",
                     rp->name,  wss/MEGA, ram_left/MEGA
                 );
             }
             continue;
         }
 
+        // We've decided to run this job
+        //
         if (log_flags.cpu_sched_debug) {
             msg_printf(rp->project, MSG_INFO,
                 "[cpu_sched_debug] scheduling %s%s",
-                rp->name,
-                rp->edf_scheduled?" (high priority)":""
+                rp->name, rp->edf_scheduled?" (high priority)":""
             );
         }
 
-        // We've decided to run this job; create an ACTIVE_TASK if needed.
+        // create an ACTIVE_TASK if needed.
         //
         if (!atp) {
             atp = get_task(rp);
@@ -1337,9 +1339,6 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
             continue;
         }
 
-        if (rp->avp->avg_ncpus > 1) {
-            scheduled_mt = true;
-        }
         ncpus_used += rp->avp->avg_ncpus;
         atp->next_scheduler_state = CPU_SCHED_SCHEDULED;
         ram_left -= wss;
@@ -1348,13 +1347,17 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
         }
     }
 
-    if (log_flags.cpu_sched_debug && ncpus_used < ncpus) {
-        msg_printf(0, MSG_INFO, "[cpu_sched_debug] using %.2f out of %d CPUs",
-            ncpus_used, ncpus
-        );
-        if (ncpus_used < ncpus) {
+    // if CPUs are starved, ask for more jobs
+    //
+    if (ncpus_used < n_usable_cpus) {
+        if (ncpus_used < n_usable_cpus) {
             request_work_fetch("CPUs idle");
         }
+        if (log_flags.cpu_sched_debug) {
+            msg_printf(0, MSG_INFO, "[cpu_sched_debug] using only %.2f out of %d CPUs",
+                ncpus_used, n_usable_cpus
+            );
+        }
     }
 
     bool check_swap = (host_info.m_swap != 0);
@@ -1620,12 +1623,14 @@ ACTIVE_TASK* CLIENT_STATE::get_task(RESULT* rp) {
     return atp;
 }
 
-// called at startup (after get_host_info())
-// and when general prefs have been parsed.
-// NOTE: GSTATE.NCPUS MUST BE 1 OR MORE; WE DIVIDE BY IT IN A COUPLE OF PLACES
+// called:
+// - at startup (after get_host_info())
+// - when general prefs have been parsed
+// - when user_active changes
+// NOTE: n_usable_cpus MUST BE 1 OR MORE; WE DIVIDE BY IT IN A COUPLE OF PLACES
 //
-void CLIENT_STATE::set_ncpus() {
-    int ncpus_old = ncpus;
+void CLIENT_STATE::set_n_usable_cpus() {
+    int ncpus_old = n_usable_cpus;
 
     // config file can say to act like host has N CPUs
     //
@@ -1636,25 +1641,29 @@ void CLIENT_STATE::set_ncpus() {
         first = false;
     }
     if (cc_config.ncpus>0) {
-        ncpus = cc_config.ncpus;
-        host_info.p_ncpus = ncpus;  // use this in scheduler requests
+        n_usable_cpus = cc_config.ncpus;
+        host_info.p_ncpus = n_usable_cpus;  // use this in scheduler requests
     } else {
         host_info.p_ncpus = original_p_ncpus;
-        ncpus = host_info.p_ncpus;
-    }
-    if (ncpus <= 0) {
-        ncpus = 1;      // shouldn't happen
+        n_usable_cpus = host_info.p_ncpus;
     }
 
-    if (global_prefs.max_ncpus_pct) {
-        ncpus = (int)((ncpus * global_prefs.max_ncpus_pct)/100);
-        if (ncpus == 0) ncpus = 1;
+    double p = global_prefs.max_ncpus_pct;
+    if (!user_active && global_prefs.niu_max_ncpus_pct>=0) {
+        p = global_prefs.niu_max_ncpus_pct;
+    }
+    if (p) {
+        n_usable_cpus = (int)((n_usable_cpus * p)/100);
     }
 
-    if (initialized && ncpus != ncpus_old) {
+    if (n_usable_cpus <= 0) {
+        n_usable_cpus = 1;
+    }
+
+    if (initialized && n_usable_cpus != ncpus_old) {
         msg_printf(0, MSG_INFO,
             "Number of usable CPUs has changed from %d to %d.",
-            ncpus_old, ncpus
+            ncpus_old, n_usable_cpus
         );
         request_schedule_cpus("Number of usable CPUs has changed");
         request_work_fetch("Number of usable CPUs has changed");
