@@ -161,45 +161,16 @@ int CLIENT_STATE::make_scheduler_request(PROJECT* p) {
     global_prefs.write(mf);
     fprintf(f, "</working_global_preferences>\n");
 
-    // send master global preferences if present and not host-specific
+    // send the oldest CPID with email hash
     //
-    if (!global_prefs.host_specific && boinc_file_exists(GLOBAL_PREFS_FILE_NAME)) {
-        FILE* fprefs = fopen(GLOBAL_PREFS_FILE_NAME, "r");
-        if (fprefs) {
-            copy_stream(fprefs, f);
-            fclose(fprefs);
-        }
-        PROJECT* pp = lookup_project(global_prefs.source_project);
-        if (pp && strlen(pp->email_hash)) {
-            fprintf(f,
-                "<global_prefs_source_email_hash>%s</global_prefs_source_email_hash>\n",
-                pp->email_hash
-            );
-        }
+    USER_CPID* ucp = user_cpids.lookup(p->email_hash);
+    if (ucp) {
+        fprintf(f,
+            "<cross_project_id>%s</cross_project_id>\n",
+            ucp->cpid
+        );
     }
 
-    // Of the projects with same email hash as this one,
-    // send the oldest cross-project ID.
-    // Use project URL as tie-breaker.
-    //
-    PROJECT* winner = p;
-    for (i=0; i<projects.size(); i++ ) {
-        PROJECT* project = projects[i];
-        if (project == p) continue;
-        if (strcmp(project->email_hash, p->email_hash)) continue;
-        if (project->cpid_time < winner->cpid_time) {
-            winner = project;
-        } else if (project->cpid_time == winner->cpid_time) {
-            if (strcmp(project->master_url, winner->master_url) < 0) {
-                winner = project;
-            }
-        }
-    }
-    fprintf(f,
-        "<cross_project_id>%s</cross_project_id>\n",
-        winner->cross_project_id
-    );
-
     time_stats.write(mf, true);
     net_stats.write(mf);
     if (global_prefs.daily_xfer_period_days) {
@@ -211,7 +182,7 @@ int CLIENT_STATE::make_scheduler_request(PROJECT* p) {
     // update hardware info, and write host info
     //
     host_info.get_host_info(false);
-    set_ncpus();
+    set_n_usable_cpus();
     host_info.write(mf, !cc_config.suppress_net_info, false);
 
     // get and write disk usage
@@ -594,10 +565,9 @@ int CLIENT_STATE::handle_scheduler_reply(
 
     // compare our URL for this project with the one returned in the reply
     // (which comes from the project's config.xml).
-    // - if http -> https transition, make the change
+    // - if http -> https transition, use the https: one from now on
+    // - if https -> http transition, keep using the https: one
     // - otherwise notify the user.
-    // This means that if a project changes its master URL,
-    // its users have to detach/reattach.
     //
     if (strlen(sr.master_url)) {
         canonicalize_master_url(sr.master_url, sizeof(sr.master_url));
@@ -612,6 +582,9 @@ int CLIENT_STATE::handle_scheduler_reply(
                 msg_printf(project, MSG_INFO,
                     "Project URL changed from http:// to https://"
                 );
+            } else if (is_https_transition(reply_url.c_str(), current_url.c_str())) {
+                // project is advertising http://, but https:// works.
+                // keep using https://
             } else {
                 msg_printf(project, MSG_USER_ALERT,
                     _("This project seems to have changed its URL.  When convenient, remove the project, then add %s"),
@@ -642,6 +615,24 @@ int CLIENT_STATE::handle_scheduler_reply(
         );
     }
 
+    // update user CPID list
+    //
+    if (strlen(project->cross_project_id) && strlen(project->email_hash)) {
+        USER_CPID *ucp = user_cpids.lookup(project->email_hash);
+        if (ucp) {
+            if (project->cpid_time < ucp->time) {
+                strcpy(ucp->cpid, project->cross_project_id);
+                ucp->time = project->cpid_time;
+            }
+        } else {
+            USER_CPID uc;
+            strcpy(uc.email_hash, project->email_hash);
+            strcpy(uc.cpid, project->cross_project_id);
+            uc.time = project->cpid_time;
+            user_cpids.cpids.push_back(uc);
+        }
+    }
+
     // show messages from server
     //
     bool got_notice = false;
@@ -682,12 +673,13 @@ int CLIENT_STATE::handle_scheduler_reply(
     // if the scheduler reply includes global preferences,
     // insert extra elements, write to disk, and parse
     //
-    if (sr.global_prefs_xml) {
+    double mod_time = sr.global_prefs_xml?GLOBAL_PREFS::parse_mod_time(sr.global_prefs_xml):0;
+    if (sr.global_prefs_xml && mod_time > gstate.global_prefs.mod_time) {
         // ignore prefs if we're using prefs from account mgr
         // BAM! currently has mixed http, https; trim off
         char* p = strchr(global_prefs.source_project, '/');
         char* q = strchr(gstate.acct_mgr_info.master_url, '/');
-        if (gstate.acct_mgr_info.using_am() && p && q && !strcmp(p, q)) {
+        if (!global_prefs.override_file_present && gstate.acct_mgr_info.using_am() && p && q && !strcmp(p, q)) {
             if (log_flags.sched_op_debug) {
                 msg_printf(project, MSG_INFO,
                     "[sched_op] ignoring prefs from project; using prefs from AM"
