@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2012 University of California
+// Copyright (C) 2022 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -22,10 +22,6 @@
 #include <math.h>
 #endif
 
-#ifdef _MSC_VER
-#define snprintf _snprintf
-#endif
-
 #include "str_replace.h"
 #include "parse.h"
 
@@ -80,12 +76,12 @@ void RESULT::clear() {
     intops_cumulative = 0;
     _state = RESULT_NEW;
     exit_status = 0;
-    stderr_out = "";
+    stderr_out.clear();
     suspended_via_gui = false;
     coproc_missing = false;
     report_immediately = false;
     not_started = false;
-    name_md5 = "";
+    name_md5.clear();
     index = 0;
     app = NULL;
     wup = NULL;
@@ -356,7 +352,7 @@ static const char* cpu_string(double ncpus) {
     return (ncpus==1)?"CPU":"CPUs";
 }
 
-int RESULT::write_gui(MIOFILE& out) {
+int RESULT::write_gui(MIOFILE& out, bool check_resources) {
     out.printf(
         "<result>\n"
         "    <name>%s</name>\n"
@@ -408,9 +404,7 @@ int RESULT::write_gui(MIOFILE& out) {
     if (atp) {
         atp->write_gui(out);
     }
-    if (!strlen(resources)) {
-        // only need to compute this string once
-        //
+    if (!strlen(resources) || check_resources) { // update resource string only when zero or when app_config is updated.
         if (avp->gpu_usage.rsc_type) {
             if (avp->gpu_usage.usage == 1) {
                 snprintf(resources, sizeof(resources),
@@ -430,7 +424,7 @@ int RESULT::write_gui(MIOFILE& out) {
             }
         } else if (avp->missing_coproc) {
             snprintf(resources, sizeof(resources),
-                "%.3g %s + %s GPU (missing)",
+                "%.3g %s + %.12s GPU (missing)",
                 avp->avg_ncpus,
                 cpu_string(avp->avg_ncpus),
                 avp->missing_coproc_name
@@ -445,6 +439,7 @@ int RESULT::write_gui(MIOFILE& out) {
             safe_strcpy(resources, " ");
         }
     }
+    // update app version resources
     if (strlen(resources)>1) {
         char buf[256];
         safe_strcpy(buf, "");
@@ -459,7 +454,7 @@ int RESULT::write_gui(MIOFILE& out) {
                     safe_strcpy(buf, n>1?" (devices ":" (device ");
                     for (int i=0; i<n; i++) {
                         char buf2[256];
-                        sprintf(buf2, "%d", cp.device_nums[coproc_indices[i]]);
+                        snprintf(buf2, sizeof(buf2), "%d", cp.device_nums[coproc_indices[i]]);
                         if (i > 0) {
                             safe_strcat(buf, ", ");
                         }
