@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2022 University of California
+// Copyright (C) 2023 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -31,6 +31,9 @@
 #include "SkinManager.h"
 #include "MainDocument.h"
 #include "version.h"
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <cstdlib>
 
 
 ////@begin XPM images
@@ -377,7 +380,6 @@ void CSkinSimple::Clear() {
     m_iPanelOpacity = DEFAULT_OPACITY;
 }
 
-
 int CSkinSimple::Parse(MIOFILE& in) {
     char buf[256];
     std::string strBuffer;
@@ -429,7 +431,7 @@ bool CSkinSimple::InitializeDelayedValidation() {
     );
     m_DialogBackgroundImage.SetDefaults(
         wxT("dialog background"), (const char**)dialog_background_image_xpm,
-        wxT("255:255:255"), BKGD_ANCHOR_HORIZ_CENTER, BKGD_ANCHOR_VERT_CENTER
+        wxGetApp().GetIsDarkMode() ? wxT("0:0:0") : wxT("255:255:255"), BKGD_ANCHOR_HORIZ_CENTER, BKGD_ANCHOR_VERT_CENTER
     );
     m_ProjectImage.SetDefaults(
         wxT("project"), (const char**)project_image_xpm
@@ -700,7 +702,7 @@ bool CSkinAdvanced::InitializeDelayedValidation() {
         if (show_error_msgs) {
             fprintf(stderr, "Skin Manager: Organization report bug url was not defined. Using defaults.\n");
         }
-        m_strOrganizationReportBugUrl = wxT("https://boinc.berkeley.edu/trac/wiki/ReportBugs");
+        m_strOrganizationReportBugUrl = wxT("https://github.com/BOINC/boinc/wiki/ReportBugs");
         wxASSERT(!m_strOrganizationReportBugUrl.IsEmpty());
     }
     return true;
@@ -978,8 +980,11 @@ wxString CSkinManager::GetSkinsLocation() {
     strSkinLocation += wxT("skins");
 #elif defined(__WXGTK__)
     strSkinLocation = wxGetApp().GetRootDirectory();
-    if (strSkinLocation.StartsWith("/usr/")) {
-        strSkinLocation += wxT("/../share/boinc-manager/skins");
+    wxString strLinuxSkinLocation = strSkinLocation + wxT("/../share/boinc-manager/skins");
+    struct stat info;
+    // check if folder exist
+    if (stat( strLinuxSkinLocation.mb_str(), &info ) == 0 && info.st_mode & S_IFDIR) {
+        strSkinLocation = strLinuxSkinLocation;
     }
     else {
         strSkinLocation += wxT("/skins");
