@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2007 University of California
+// Copyright (C) 2023 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -18,11 +18,7 @@
 #if defined(_WIN32)
 #include "boinc_win.h"
 #else
-#ifdef _USING_FCGI_
-#include "boinc_fcgi.h"
-#else
-#include <cstdio>
-#endif
+#include "boinc_stdio.h"
 #include <cstring>
 #include <cstdlib>
 #include <cmath>
@@ -50,10 +46,6 @@
 
 #include "coproc.h"
 
-#ifndef _USING_FCGI_
-using std::perror;
-#endif
-
 int COPROC_REQ::parse(XML_PARSER& xp) {
     safe_strcpy(type, "");
     count = 0;
@@ -105,7 +97,7 @@ void COPROC::write_xml(MIOFILE& f, bool scheduler_rpc) {
         "   <peak_flops>%f</peak_flops>\n",
         type, count, peak_flops
     );
-    
+
     if (scheduler_rpc) {
         write_request(f);
     }
@@ -113,7 +105,7 @@ void COPROC::write_xml(MIOFILE& f, bool scheduler_rpc) {
     if (have_opencl) {
         opencl_prop.write_xml(f, "coproc_opencl");
     }
-    
+
     f.printf("</coproc>\n");
 }
 
@@ -140,6 +132,13 @@ int COPROC::parse(XML_PARSER& xp) {
     while (!xp.get_tag()) {
         if (!xp.is_tag) continue;
         if (xp.match_tag("/coproc")) {
+            // The client reports the type of Apple GPUs as the model
+            // (e.g. "Apple M1").
+            // Change it to just "Apple".
+            //
+            if (strstr(type, "Apple")) {
+                strcpy(type, "Apple");
+            }
             if (!strlen(type)) return ERR_XML_PARSE;
             clear_usage();
             return 0;
@@ -267,7 +266,7 @@ int COPROCS::parse(XML_PARSER& xp) {
             if (!retval) {
                 coprocs[n_rsc++] = cp;
             } else {
-                fprintf(stderr, "failed to parse <coproc>: %d\n", retval);
+                boinc::fprintf(stderr, "failed to parse <coproc>: %d\n", retval);
             }
         }
     }
@@ -280,7 +279,7 @@ void COPROCS::write_xml(MIOFILE&, bool) {
 #else
 void COPROCS::write_xml(MIOFILE& mf, bool scheduler_rpc) {
     mf.printf("    <coprocs>\n");
-    
+
     for (int i=1; i<n_rsc; i++) {
         switch (coproc_type_name_to_num(coprocs[i].type)) {
         case PROC_TYPE_NVIDIA_GPU:
@@ -296,7 +295,7 @@ void COPROCS::write_xml(MIOFILE& mf, bool scheduler_rpc) {
             coprocs[i].write_xml(mf, scheduler_rpc);
         }
     }
-    
+
     mf.printf("    </coprocs>\n");
 }
 #endif
@@ -397,7 +396,7 @@ void COPROC_NVIDIA::write_xml(MIOFILE& f, bool scheduler_rpc) {
             pci_infos[i].write(f);
         }
     }
-    
+
     f.printf("</coproc_cuda>\n");
 }
 #endif
@@ -717,7 +716,7 @@ void COPROC_ATI::write_xml(MIOFILE& f, bool scheduler_rpc) {
     if (have_opencl) {
         opencl_prop.write_xml(f, "coproc_opencl");
     }
-        
+
     f.printf("</coproc_ati>\n");
 }
 #endif
@@ -858,8 +857,8 @@ void COPROC_ATI::set_peak_flops() {
         // Per: https://en.wikipedia.org/wiki/List_of_AMD_graphics_processing_units
         //
         // clock is in MHz
-        x = opencl_prop.max_compute_units * 
-            opencl_prop.amd_simd_per_compute_unit * 
+        x = opencl_prop.max_compute_units *
+            opencl_prop.amd_simd_per_compute_unit *
             opencl_prop.amd_simd_width *
             opencl_prop.amd_simd_instruction_width *
             2 *
@@ -924,7 +923,7 @@ void COPROC_INTEL::write_xml(MIOFILE& f, bool scheduler_rpc) {
     if (have_opencl) {
         opencl_prop.write_xml(f, "coproc_opencl");
     }
-        
+
     f.printf("</coproc_intel_gpu>\n");
 }
 #endif
@@ -981,7 +980,7 @@ int COPROC_INTEL::parse(XML_PARSER& xp) {
 //
 // However, there is some question of the accuracy of this due to Intel's
 // Turbo Boost and Dynamic Frequency technologies.
-// 
+//
 void COPROC_INTEL::set_peak_flops() {
     double x = 0;
     if (opencl_prop.max_compute_units) {
