@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2008 University of California
+// Copyright (C) 2023 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -41,6 +41,14 @@
 
 #include "diagnostics_win.h"
 
+#ifndef PRIz
+#ifdef _WIN64
+#define PRIz "ll"
+#else
+#define PRIz "l"
+#endif
+#endif
+
 // NtQuerySystemInformation
 typedef NTSTATUS (WINAPI *tNTQSI)(
     ULONG SystemInformationClass,
@@ -57,15 +65,15 @@ BOOL diagnostics_get_registry_value(LPCSTR lpName, LPDWORD lpdwType, LPDWORD lpd
 	HKEY  hKey;
 
     // Detect platform information
-    OSVERSIONINFO osvi; 
+    OSVERSIONINFO osvi;
     osvi.dwOSVersionInfoSize = sizeof(osvi);
     GetVersionEx(&osvi);
 
     if (VER_PLATFORM_WIN32_WINDOWS == osvi.dwPlatformId) {
 		lRetVal = RegOpenKeyExA(
-            HKEY_LOCAL_MACHINE, 
+            HKEY_LOCAL_MACHINE,
             "SOFTWARE\\Space Sciences Laboratory, U.C. Berkeley\\BOINC Diagnostics",
-			(DWORD)NULL, 
+			(DWORD)NULL,
             KEY_READ,
             &hKey
         );
@@ -114,9 +122,9 @@ struct BOINC_THREADLISTENTRY {
     DWORD               thread_id;
     HANDLE              thread_handle;
     BOOL                crash_suspend_exempt;
-    FLOAT               crash_kernel_time;
-    FLOAT               crash_user_time;
-    FLOAT               crash_wait_time;
+    double              crash_kernel_time;
+    double              crash_user_time;
+    ULONG               crash_wait_time;
     INT                 crash_priority;
     INT                 crash_base_priority;
     INT                 crash_state;
@@ -136,13 +144,13 @@ int diagnostics_init_thread_entry(BOINC_THREADLISTENTRY *entry) {
     entry->crash_suspend_exempt = FALSE;
     entry->crash_kernel_time = 0.0;
     entry->crash_user_time = 0.0;
-    entry->crash_wait_time = 0.0;
+    entry->crash_wait_time = 0;
     entry->crash_priority = 0;
     entry->crash_base_priority = 0;
     entry->crash_state = 0;
     entry->crash_wait_reason = 0;
     entry->crash_exception_record = NULL;
-    strlcpy(entry->crash_message, "", sizeof(entry->crash_message));
+    entry->crash_message[0] = '\0';
     return 0;
 }
 
@@ -159,7 +167,7 @@ int diagnostics_init_thread_list() {
     hThreadListSync = CreateMutex(NULL, TRUE, NULL);
     if (!hThreadListSync) {
         fprintf(
-            stderr, "diagnostics_init_thread_list(): Creating hThreadListSync failed, GLE %d\n", GetLastError()
+            stderr, "diagnostics_init_thread_list(): Creating hThreadListSync failed, GLE %lu\n", GetLastError()
         );
         retval = GetLastError();
     } else {
@@ -252,10 +260,10 @@ int diagnostics_get_process_information(PVOID* ppBuffer, PULONG pcbBuffer) {
         );
 
         if (Status == STATUS_INFO_LENGTH_MISMATCH) {
-            HeapFree(hHeap, (DWORD)NULL, *ppBuffer);
+            HeapFree(hHeap, 0, *ppBuffer);
             *pcbBuffer *= 2;
         } else if (!NT_SUCCESS(Status)) {
-            HeapFree(hHeap, (DWORD)NULL, *ppBuffer);
+            HeapFree(hHeap, 0, *ppBuffer);
             retval = Status;
         }
     } while (Status == STATUS_INFO_LENGTH_MISMATCH);
@@ -303,9 +311,9 @@ int diagnostics_update_thread_list() {
                 pThreadEntry = diagnostics_find_thread_entry((DWORD)(uintptr_t)pThread->ClientId.UniqueThread);
 
                 if (pThreadEntry) {
-                    pThreadEntry->crash_kernel_time = (FLOAT)pThread->KernelTime.QuadPart;
-                    pThreadEntry->crash_user_time = (FLOAT)pThread->UserTime.QuadPart;
-                    pThreadEntry->crash_wait_time = (FLOAT)pThread->WaitTime;
+                    pThreadEntry->crash_kernel_time = pThread->KernelTime.QuadPart / 1e7;
+                    pThreadEntry->crash_user_time = pThread->UserTime.QuadPart / 1e7;
+                    pThreadEntry->crash_wait_time = pThread->WaitTime;
                     pThreadEntry->crash_priority = pThread->Priority;
                     pThreadEntry->crash_base_priority = pThread->BasePriority;
                     pThreadEntry->crash_state = pThread->State;
@@ -321,9 +329,9 @@ int diagnostics_update_thread_list() {
                     diagnostics_init_thread_entry(pThreadEntry);
                     pThreadEntry->thread_id = (DWORD)(uintptr_t)(pThread->ClientId.UniqueThread);
                     pThreadEntry->thread_handle = hThread;
-                    pThreadEntry->crash_kernel_time = (FLOAT)pThread->KernelTime.QuadPart;
-                    pThreadEntry->crash_user_time = (FLOAT)pThread->UserTime.QuadPart;
-                    pThreadEntry->crash_wait_time = (FLOAT)pThread->WaitTime;
+                    pThreadEntry->crash_kernel_time = pThread->KernelTime.QuadPart / 1e7;
+                    pThreadEntry->crash_user_time = pThread->UserTime.QuadPart / 1e7;
+                    pThreadEntry->crash_wait_time = pThread->WaitTime;
                     pThreadEntry->crash_priority = pThread->Priority;
                     pThreadEntry->crash_base_priority = pThread->BasePriority;
                     pThreadEntry->crash_state = pThread->State;
@@ -342,7 +350,7 @@ int diagnostics_update_thread_list() {
 
     // Release resources
     if (hThreadListSync) ReleaseMutex(hThreadListSync);
-    if (pBuffer) HeapFree(GetProcessHeap(), (DWORD)NULL, pBuffer);
+    if (pBuffer) HeapFree(GetProcessHeap(), 0, pBuffer);
 
     return 0;
 }
@@ -448,7 +456,7 @@ int diagnostics_is_thread_exempt_suspend(long thread_id) {
 
 
 // Set the current thread's crash message.
-int diagnostics_set_thread_crash_message(char* message) {
+int diagnostics_set_thread_crash_message(const char* message) {
     HANDLE hThread;
     BOINC_THREADLISTENTRY *pThreadEntry = NULL;
 
@@ -458,12 +466,12 @@ int diagnostics_set_thread_crash_message(char* message) {
     pThreadEntry = diagnostics_find_thread_entry(GetCurrentThreadId());
     if (pThreadEntry) {
         int buffer_used = snprintf(
-            pThreadEntry->crash_message, 
+            pThreadEntry->crash_message,
             sizeof(pThreadEntry->crash_message),
             "%s",
             message
         );
-        if ((sizeof(pThreadEntry->crash_message) == buffer_used) || (-1 == buffer_used)) { 
+        if ((sizeof(pThreadEntry->crash_message) == buffer_used) || (-1 == buffer_used)) {
             pThreadEntry->crash_message[sizeof(pThreadEntry->crash_message)-1] = '\0';
         }
     } else {
@@ -482,12 +490,12 @@ int diagnostics_set_thread_crash_message(char* message) {
         pThreadEntry->thread_id = GetCurrentThreadId();
         pThreadEntry->thread_handle = hThread;
         int buffer_used = snprintf(
-            pThreadEntry->crash_message, 
+            pThreadEntry->crash_message,
             sizeof(pThreadEntry->crash_message),
             "%s",
             message
         );
-        if ((sizeof(pThreadEntry->crash_message) == buffer_used) || (-1 == buffer_used)) { 
+        if ((sizeof(pThreadEntry->crash_message) == buffer_used) || (-1 == buffer_used)) {
             pThreadEntry->crash_message[sizeof(pThreadEntry->crash_message)-1] = '\0';
         }
         diagnostics_threads.push_back(pThreadEntry);
@@ -504,7 +512,7 @@ int diagnostics_set_thread_crash_message(char* message) {
 //
 // See: http://support.microsoft.com/?kbid=837372
 //
-char* diagnostics_format_thread_state(int thread_state) {
+const char* diagnostics_format_thread_state(int thread_state) {
     switch(thread_state) {
         case StateInitialized: return "Initialized";
         case StateReady: return "Ready";
@@ -522,7 +530,7 @@ char* diagnostics_format_thread_state(int thread_state) {
 //
 // See: http://support.microsoft.com/?kbid=837372
 //
-char* diagnostics_format_thread_wait_reason(int thread_wait_reason) {
+const char* diagnostics_format_thread_wait_reason(int thread_wait_reason) {
     switch(thread_wait_reason) {
         case ThreadWaitReasonExecutive: return "Executive";
         case ThreadWaitReasonFreePage: return "FreePage";
@@ -553,7 +561,7 @@ char* diagnostics_format_thread_wait_reason(int thread_wait_reason) {
 //
 // See: http://msdn.microsoft.com/library/default.asp?url=/library/en-us/dllproc/base/scheduling_priorities.asp
 //
-char* diagnostics_format_process_priority(int process_priority) {
+const char* diagnostics_format_process_priority(int process_priority) {
     switch(process_priority) {
         case IDLE_PRIORITY_CLASS: return "Idle";
         case BELOW_NORMAL_PRIORITY_CLASS: return "Below Normal";
@@ -570,7 +578,7 @@ char* diagnostics_format_process_priority(int process_priority) {
 //
 // See: http://msdn.microsoft.com/library/default.asp?url=/library/en-us/dllproc/base/scheduling_priorities.asp
 //
-char* diagnostics_format_thread_priority(int thread_priority) {
+const char* diagnostics_format_thread_priority(int thread_priority) {
     switch(thread_priority) {
         case THREAD_PRIORITY_IDLE: return "Idle";
         case THREAD_PRIORITY_LOWEST: return "Lowest";
@@ -639,7 +647,7 @@ int diagnostics_init_message_monitor() {
     hMessageMonitorSync = CreateMutex(NULL, TRUE, NULL);
     if (!hMessageMonitorSync) {
         fprintf(
-            stderr, "diagnostics_init_message_monitor(): Creating hMessageMonitorSync failed, GLE %d\n", GetLastError()
+            stderr, "diagnostics_init_message_monitor(): Creating hMessageMonitorSync failed, GLE %lu\n", GetLastError()
         );
     }
 
@@ -650,7 +658,7 @@ int diagnostics_init_message_monitor() {
     diagnostics_monitor_messages.clear();
 
     // Check the registry to see if we are allowed to capture debugger messages.
-    //   Apparently many audio and visual payback programs dump serious
+    //   Apparently many audio and visual playback programs dump serious
     //   amounts of data to the debugger viewport even on a release build.
     //   When this feature is enabled it slows down the replay of DVDs and CDs
     //   such that they become jerky and unpleasent to watch or listen too.
@@ -673,42 +681,42 @@ int diagnostics_init_message_monitor() {
         hMessageAckEvent = CreateEventA(&sa, FALSE, FALSE, "DBWIN_BUFFER_READY");
         if (!hMessageAckEvent) {
             fprintf(
-                stderr, "diagnostics_init_message_monitor(): Creating hMessageAckEvent failed, GLE %d\n", GetLastError()
+                stderr, "diagnostics_init_message_monitor(): Creating hMessageAckEvent failed, GLE %lu\n", GetLastError()
             );
         }
 
         hMessageReadyEvent = CreateEventA(&sa, FALSE, FALSE, "DBWIN_DATA_READY");
         if (!hMessageReadyEvent) {
             fprintf(
-                stderr, "diagnostics_init_message_monitor(): Creating hMessageReadyEvent failed, GLE %d\n", GetLastError()
+                stderr, "diagnostics_init_message_monitor(): Creating hMessageReadyEvent failed, GLE %lu\n", GetLastError()
             );
         }
 
         hMessageQuitEvent = CreateEventA(NULL, FALSE, FALSE, NULL);
         if (!hMessageQuitEvent) {
             fprintf(
-                stderr, "diagnostics_init_message_monitor(): Creating hMessageQuitEvent failed, GLE %d\n", GetLastError()
+                stderr, "diagnostics_init_message_monitor(): Creating hMessageQuitEvent failed, GLE %lu\n", GetLastError()
             );
         }
 
         hMessageQuitFinishedEvent = CreateEventA(NULL, FALSE, FALSE, NULL);
         if (!hMessageQuitFinishedEvent) {
             fprintf(
-                stderr, "diagnostics_init_message_monitor(): Creating hMessageQuitFinishedEvent failed, GLE %d\n", GetLastError()
+                stderr, "diagnostics_init_message_monitor(): Creating hMessageQuitFinishedEvent failed, GLE %lu\n", GetLastError()
             );
         }
 
         hMessageSharedMap = CreateFileMappingA(
             INVALID_HANDLE_VALUE,    // use paging file
-            &sa,                     // default security 
+            &sa,                     // default security
             PAGE_READWRITE,          // read/write access
-            0,                       // max. object size 
-            sizeof(DEBUGGERMESSAGE), // buffer size  
+            0,                       // max. object size
+            sizeof(DEBUGGERMESSAGE), // buffer size
             "DBWIN_BUFFER"           // name of mapping object
         );
         if (!hMessageSharedMap) {
             fprintf(
-                stderr, "diagnostics_init_message_monitor(): CreateFileMapping hMessageSharedMap failed, GLE %d\n", GetLastError()
+                stderr, "diagnostics_init_message_monitor(): CreateFileMapping hMessageSharedMap failed, GLE %lu\n", GetLastError()
             );
         }
 
@@ -721,7 +729,7 @@ int diagnostics_init_message_monitor() {
         );
         if (!pMessageBuffer) {
             fprintf(
-                stderr, "diagnostics_init_message_monitor(): MapViewOfFile pMessageBuffer failed, GLE %d\n", GetLastError()
+                stderr, "diagnostics_init_message_monitor(): MapViewOfFile pMessageBuffer failed, GLE %lu\n", GetLastError()
             );
         }
 
@@ -763,7 +771,7 @@ int diagnostics_finish_message_monitor() {
     //   MessageMonitorSync mutex.
     WaitForSingleObject(hMessageQuitFinishedEvent, INFINITE);
     WaitForSingleObject(hMessageMonitorSync, INFINITE);
-  
+
 
     // Now clean up everything we can.
     //
@@ -797,12 +805,12 @@ int diagnostics_message_monitor_dump() {
     WaitForSingleObject(hMessageMonitorSync, INFINITE);
 
     fprintf(stderr, "\n*** Debug Message Dump ****\n");
-    
+
     // Clear out any previous messages.
     for (i=0; i<diagnostics_monitor_messages.size(); i++) {
         pMessageEntry = diagnostics_monitor_messages[i];
         fprintf(
-            stderr, 
+            stderr,
             "[%s] %s",
             time_to_string(pMessageEntry->timestamp),
             pMessageEntry->message.c_str()
@@ -820,7 +828,7 @@ int diagnostics_message_monitor_dump() {
 
 // This thread monitors the shared memory buffer used to pass debug messages
 //   around.  due to an anomaly in the Windows debug environment it is
-//   suggested that a sleep(0) be introduced before any 
+//   suggested that a sleep(0) be introduced before any
 //   SetEvent/ResetEvent/PulseEvent function is called.
 //
 // See: http://support.microsoft.com/kb/q173260/
@@ -836,7 +844,7 @@ UINT WINAPI diagnostics_message_monitor(LPVOID /* lpParameter */) {
     HANDLE      hEvents[2];
 
     // Make sure this thread doesn't get suspended during
-    //   a crash dump, the DBGHELP library is pretty verbose.
+    //   a crash dump: the DBGHELP library is pretty verbose.
     //   Suspending this thread will cause a deadlock.
     diagnostics_set_thread_exempt_suspend();
 
@@ -853,7 +861,7 @@ UINT WINAPI diagnostics_message_monitor(LPVOID /* lpParameter */) {
     SetEvent(hMessageAckEvent);
 
     while (bContinue) {
-        dwEvent = WaitForMultipleObjects( 
+        dwEvent = WaitForMultipleObjects(
             2,           // number of objects in array
             hEvents,     // array of objects
             FALSE,       // wait for any
@@ -865,7 +873,7 @@ UINT WINAPI diagnostics_message_monitor(LPVOID /* lpParameter */) {
 
                 // We are shutting down so lets cleanup and exit.
                 bContinue = false;
-                
+
                 break;
 
             // hMessageReadyEvent was signaled.
@@ -889,7 +897,7 @@ UINT WINAPI diagnostics_message_monitor(LPVOID /* lpParameter */) {
                     // Message from a different process.
 
                     // Is this the same message as before?
-                    if ((dwRepeatMessageProcessId != pMessageBuffer->dwProcessId) || 
+                    if ((dwRepeatMessageProcessId != pMessageBuffer->dwProcessId) ||
                         (strRepeatMessage != pMessageBuffer->data)
                     ) {
                         dwRepeatMessageCounter = 0;
@@ -1031,7 +1039,7 @@ static HANDLE hExceptionMonitorStartedEvent = NULL;
 static HANDLE hExceptionDetectedEvent = NULL;
 static HANDLE hExceptionQuitEvent = NULL;
 static HANDLE hExceptionQuitFinishedEvent = NULL;
-static CRITICAL_SECTION csExceptionMonitorFallback; 
+static CRITICAL_SECTION csExceptionMonitorFallback;
 
 // Initialize the needed structures and startup the unhandled exception
 //   monitor thread.
@@ -1048,7 +1056,7 @@ int diagnostics_init_unhandled_exception_monitor() {
     hExceptionMonitorHalt = CreateMutex(NULL, FALSE, NULL);
     if (!hExceptionMonitorHalt) {
         fprintf(
-            stderr, "diagnostics_init_unhandled_exception_monitor(): Creating hExceptionMonitorHalt failed, GLE %d\n", GetLastError()
+            stderr, "diagnostics_init_unhandled_exception_monitor(): Creating hExceptionMonitorHalt failed, GLE %lu\n", GetLastError()
         );
     }
 
@@ -1057,7 +1065,7 @@ int diagnostics_init_unhandled_exception_monitor() {
     hExceptionMonitorStartedEvent = CreateEvent(NULL, FALSE, FALSE, NULL);
     if (!hExceptionMonitorStartedEvent) {
         fprintf(
-            stderr, "diagnostics_init_unhandled_exception_monitor(): Creating hExceptionMonitorStartedEvent failed, GLE %d\n", GetLastError()
+            stderr, "diagnostics_init_unhandled_exception_monitor(): Creating hExceptionMonitorStartedEvent failed, GLE %lu\n", GetLastError()
         );
     }
 
@@ -1067,7 +1075,7 @@ int diagnostics_init_unhandled_exception_monitor() {
     hExceptionDetectedEvent = CreateEvent(NULL, FALSE, FALSE, NULL);
     if (!hExceptionDetectedEvent) {
         fprintf(
-            stderr, "diagnostics_init_unhandled_exception_monitor(): Creating hExceptionDetectedEvent failed, GLE %d\n", GetLastError()
+            stderr, "diagnostics_init_unhandled_exception_monitor(): Creating hExceptionDetectedEvent failed, GLE %lu\n", GetLastError()
         );
     }
 
@@ -1076,13 +1084,13 @@ int diagnostics_init_unhandled_exception_monitor() {
     hExceptionQuitEvent = CreateEvent(NULL, FALSE, FALSE, NULL);
     if (!hExceptionQuitEvent) {
         fprintf(
-            stderr, "diagnostics_init_unhandled_exception_monitor(): Creating hExceptionQuitEvent failed, GLE %d\n", GetLastError()
+            stderr, "diagnostics_init_unhandled_exception_monitor(): Creating hExceptionQuitEvent failed, GLE %lu\n", GetLastError()
         );
     }
     hExceptionQuitFinishedEvent = CreateEvent(NULL, FALSE, FALSE, NULL);
     if (!hExceptionQuitFinishedEvent) {
         fprintf(
-            stderr, "diagnostics_init_unhandled_exception_monitor(): Creating hExceptionQuitFinishedEvent failed, GLE %d\n", GetLastError()
+            stderr, "diagnostics_init_unhandled_exception_monitor(): Creating hExceptionQuitFinishedEvent failed, GLE %lu\n", GetLastError()
         );
     }
 
@@ -1115,6 +1123,7 @@ int diagnostics_init_unhandled_exception_monitor() {
         // Wait until the exception monitor is ready for business.
         //
         WaitForSingleObject(hExceptionMonitorStartedEvent, INFINITE);
+        CloseHandle(hExceptionMonitorStartedEvent);
 
     }
 
@@ -1220,7 +1229,7 @@ int diagnostics_capture_foreground_window(PBOINC_WINDOWCAPTURE window_info) {
 	    //   handler.
 	    if (window_info->window_process_id != GetCurrentProcessId()) {
 		    GetWindowTextA(
-			    window_info->hwnd, 
+			    window_info->hwnd,
 			    window_info->window_name,
 			    sizeof(window_info->window_name)
 		    );
@@ -1246,8 +1255,8 @@ int diagnostics_foreground_window_dump(PBOINC_WINDOWCAPTURE window_info) {
         "*** Foreground Window Data ***\n"
         "    Window Name      : %s\n"
         "    Window Class     : %s\n"
-        "    Window Process ID: %x\n"
-        "    Window Thread ID : %x\n\n",
+        "    Window Process ID: %lu\n"
+        "    Window Thread ID : %lu\n\n",
         window_info->window_name,
         window_info->window_class,
         window_info->window_process_id,
@@ -1263,18 +1272,18 @@ int diagnostics_foreground_window_dump(PBOINC_WINDOWCAPTURE window_info) {
 int diagnostics_dump_process_information() {
     // Header
     fprintf(
-        stderr, 
+        stderr,
         "*** Dump of the Process Statistics: ***\n\n"
     );
 
     // I/O Counters
     fprintf(
-        stderr, 
+        stderr,
         "- I/O Operations Counters -\n"
-        "Read: %d, Write: %d, Other %d\n"
+        "Read: %llu, Write: %llu, Other %llu\n"
         "\n"
         "- I/O Transfers Counters -\n"
-        "Read: %d, Write: %d, Other %d\n"
+        "Read: %llu, Write: %llu, Other %llu\n"
         "\n",
         diagnostics_process.io_counters.ReadOperationCount,
         diagnostics_process.io_counters.WriteOperationCount,
@@ -1286,19 +1295,19 @@ int diagnostics_dump_process_information() {
 
     // VM Counters
     fprintf(
-        stderr, 
+        stderr,
         "- Paged Pool Usage -\n"
-        "QuotaPagedPoolUsage: %d, QuotaPeakPagedPoolUsage: %d\n"
-        "QuotaNonPagedPoolUsage: %d, QuotaPeakNonPagedPoolUsage: %d\n"
+        "QuotaPagedPoolUsage: %" PRIz "u, QuotaPeakPagedPoolUsage: %" PRIz "u\n"
+        "QuotaNonPagedPoolUsage: %" PRIz "u, QuotaPeakNonPagedPoolUsage: %" PRIz "u\n"
         "\n"
         "- Virtual Memory Usage -\n"
-        "VirtualSize: %d, PeakVirtualSize: %d\n"
+        "VirtualSize: %" PRIz "u, PeakVirtualSize: %" PRIz "u\n"
         "\n"
         "- Pagefile Usage -\n"
-        "PagefileUsage: %d, PeakPagefileUsage: %d\n"
+        "PagefileUsage: %" PRIz "u, PeakPagefileUsage: %" PRIz "u\n"
         "\n"
         "- Working Set Size -\n"
-        "WorkingSetSize: %d, PeakWorkingSetSize: %d, PageFaultCount: %d\n"
+        "WorkingSetSize: %" PRIz "u, PeakWorkingSetSize: %" PRIz "u, PageFaultCount: %lu\n"
         "\n",
         diagnostics_process.vm_counters.QuotaPagedPoolUsage,
         diagnostics_process.vm_counters.QuotaPeakPagedPoolUsage,
@@ -1325,24 +1334,22 @@ int diagnostics_dump_thread_information(BOINC_THREADLISTENTRY *pThreadEntry) {
     if (pThreadEntry->crash_state == StateWait) {
         strStatusExtra += "Wait Reason: ";
         strStatusExtra += diagnostics_format_thread_wait_reason(pThreadEntry->crash_wait_reason);
-        strStatusExtra += ", ";
     } else {
         strStatusExtra += "Base Priority: ";
         strStatusExtra += diagnostics_format_thread_priority(pThreadEntry->crash_base_priority);
         strStatusExtra += ", ";
         strStatusExtra += "Priority: ";
         strStatusExtra += diagnostics_format_thread_priority(pThreadEntry->crash_priority);
-        strStatusExtra += ", ";
     }
 
     fprintf(
-        stderr, 
-        "*** Dump of thread ID %d (state: %s): ***\n\n"
+        stderr,
+        "*** Dump of thread ID %lu (state: %s): ***\n\n"
         "- Information -\n"
         "Status: %s, "
-        "Kernel Time: %f, "
-        "User Time: %f, "
-        "Wait Time: %f\n"
+        "Kernel Time: %.3f, "
+        "User Time: %.3f, "
+        "Wait Time: %lu\n"
         "\n",
         pThreadEntry->thread_id,
         diagnostics_format_thread_state(pThreadEntry->crash_state),
@@ -1358,10 +1365,10 @@ int diagnostics_dump_thread_information(BOINC_THREADLISTENTRY *pThreadEntry) {
 
 // Provide a generic way to format exceptions
 //
-int diagnostics_dump_generic_exception(char* exception_desc, DWORD exception_code, PVOID exception_address) {
+int diagnostics_dump_generic_exception(const char* exception_desc, DWORD exception_code, PVOID exception_address) {
     fprintf(
-        stderr, 
-        "Reason: %s (0x%x) at address 0x%p\n\n",
+        stderr,
+        "Reason: %s (0x%lx) at address 0x%p\n\n",
         exception_desc,
         exception_code,
         exception_address
@@ -1411,29 +1418,35 @@ int diagnostics_dump_exception_record(PEXCEPTION_POINTERS pExPtrs) {
             fprintf(stderr, "%s\n\n", windows_format_error_string(exception_code, message, sizeof(message)));
             break;
         case 0xE06D7363:
-            diagnostics_dump_generic_exception("Out Of Memory (C++ Exception)", exception_code, exception_address);
+            diagnostics_dump_generic_exception("(C++ Exception)", exception_code, exception_address);
             break;
         case EXCEPTION_ACCESS_VIOLATION:
             safe_strcpy(status, "Access Violation");
             safe_strcpy(substatus, "");
             if (pExPtrs->ExceptionRecord->NumberParameters == 2) {
                 switch(pExPtrs->ExceptionRecord->ExceptionInformation[0]) {
-                case 0: // read attempt
+                case EXCEPTION_READ_FAULT:
                     snprintf(substatus, sizeof(substatus),
-                        "read attempt to address 0x%8.8X",
-                        pExPtrs->ExceptionRecord->ExceptionInformation[1]
+                        "read attempt from address 0x%p",
+                        (void*)pExPtrs->ExceptionRecord->ExceptionInformation[1]
                     );
                     break;
-                case 1: // write attempt
+                case EXCEPTION_WRITE_FAULT:
                     snprintf(substatus, sizeof(substatus),
-                        "write attempt to address 0x%8.8X",
-                        pExPtrs->ExceptionRecord->ExceptionInformation[1]
+                        "write attempt to address 0x%p",
+                        (void*)pExPtrs->ExceptionRecord->ExceptionInformation[1]
+                    );
+                    break;
+                case EXCEPTION_EXECUTE_FAULT:
+                    snprintf(substatus, sizeof(substatus),
+                        "execute attempt at address 0x%p",
+                        (void*)pExPtrs->ExceptionRecord->ExceptionInformation[1]
                     );
                     break;
                 }
             }
             fprintf(stderr,
-                "Reason: %s (0x%x) at address 0x%p %s\n\n",
+                "Reason: %s (0x%lx) at address 0x%p %s\n\n",
                 status, exception_code, exception_address, substatus
             );
             break;
@@ -1524,7 +1537,7 @@ UINT diagnostics_determine_exit_code() {
     size = diagnostics_threads.size();
     for (uiIndex = 0; uiIndex < size; uiIndex++) {
         if (diagnostics_threads[uiIndex]->crash_exception_record) {
-            uiReturn = 
+            uiReturn =
                 diagnostics_threads[uiIndex]->crash_exception_record->ExceptionRecord->ExceptionCode;
         }
     }
@@ -1560,7 +1573,7 @@ UINT WINAPI diagnostics_unhandled_exception_monitor(LPVOID /* lpParameter */) {
     SetEvent(hExceptionMonitorStartedEvent);
 
     while (bContinue) {
-        dwEvent = WaitForMultipleObjects( 
+        dwEvent = WaitForMultipleObjects(
             2,           // number of objects in array
             hEvents,     // array of objects
             FALSE,       // wait for any
@@ -1570,9 +1583,9 @@ UINT WINAPI diagnostics_unhandled_exception_monitor(LPVOID /* lpParameter */) {
             // hExceptionQuitEvent was signaled.
             case WAIT_OBJECT_0 + 0:
 
-                // We are shutting down so lets cleanup and exit.
+                // We are shutting down, so let's clean up and exit.
                 bContinue = false;
-                
+
                 break;
 
             // hExceptionDetectedEvent was signaled.
@@ -1650,10 +1663,10 @@ UINT WINAPI diagnostics_unhandled_exception_monitor(LPVOID /* lpParameter */) {
                                         EXCEPTION_EXECUTE_HANDLER
                                     );
                                 } else {
-                                    // Suspend thread before extracting the contexts, 
+                                    // Suspend thread before extracting the contexts,
                                     //   otherwise it'll be trash.
                                     SuspendThread(pThreadEntry->thread_handle);
-                                    
+
                                     // Get the thread context
                                     memset(&c, 0, sizeof(CONTEXT));
                                     c.ContextFlags = CONTEXT_FULL;
@@ -1730,7 +1743,7 @@ void setup_no_ignore() {
 
 LONG pass_to_signal_handler(int signum) {
     void (*handler)(int);
-    
+
     if (!setup_arrays) {
         setup_arrays=1;
         setup_no_ignore();
@@ -1751,8 +1764,8 @@ LONG pass_to_signal_handler(int signum) {
         if (!no_ignore[signum]) {
             // Yes? Attempt to ignore the exception.
             return EXCEPTION_CONTINUE_EXECUTION;
-        } else {  
-            return EXCEPTION_CONTINUE_SEARCH; 
+        } else {
+            return EXCEPTION_CONTINUE_SEARCH;
         }
     }
 
@@ -1772,7 +1785,7 @@ LONG pass_to_signal_handler(int signum) {
 // standard signals.
 LONG diagnostics_check_signal_handlers(PEXCEPTION_POINTERS pExPtrs) {
     switch (pExPtrs->ExceptionRecord->ExceptionCode) {
-      case CONTROL_C_EXIT:                
+      case CONTROL_C_EXIT:
                                        return pass_to_signal_handler(SIGINT);
       case EXCEPTION_BREAKPOINT:
       case EXCEPTION_SINGLE_STEP:
@@ -1786,14 +1799,14 @@ LONG diagnostics_check_signal_handlers(PEXCEPTION_POINTERS pExPtrs) {
       case EXCEPTION_FLT_INEXACT_RESULT:
       case EXCEPTION_FLT_INVALID_OPERATION:
       case EXCEPTION_FLT_OVERFLOW:
-      case EXCEPTION_FLT_UNDERFLOW:      
+      case EXCEPTION_FLT_UNDERFLOW:
                                        {
                                          LONG rv=pass_to_signal_handler(SIGFPE);
                                          /* MS claims ignoring an FP signal
                                           * results in an unknown FP state.
                                           * Does an _fpreset() help?
                                           */
-                                         if (rv != EXCEPTION_CONTINUE_SEARCH) 
+                                         if (rv != EXCEPTION_CONTINUE_SEARCH)
                                              _fpreset();
                                          return rv;
                                        }
@@ -1831,7 +1844,7 @@ LONG diagnostics_check_signal_handlers(PEXCEPTION_POINTERS pExPtrs) {
 LONG CALLBACK boinc_catch_signal(PEXCEPTION_POINTERS pExPtrs) {
 
     // Check whether somone has installed a standard C signal handler to
-    // handle this exception. 
+    // handle this exception.
     if (diagnostics_check_signal_handlers(pExPtrs) == EXCEPTION_CONTINUE_EXECUTION) {
         return EXCEPTION_CONTINUE_EXECUTION;
     }
