@@ -168,7 +168,7 @@ def account_file_name(url):
 
 def srcdir(location):
     return os.path.join(options.srcdir, location)
-    
+
 def builddir(location):
     return os.path.join(boinc_path_config.TOP_BUILD_DIR, location)
 
@@ -262,7 +262,7 @@ def create_project_dirs(dest_dir):
                    'html/cache',
                    'html/inc',
                    'html/inc/password_compat',
-                   'html/inc/random_compat',  
+                   'html/inc/random_compat',
                    'html/inc/ReCaptcha',
                    'html/inc/ReCaptcha/RequestMethod',
                    'html/languages',
@@ -342,7 +342,7 @@ def install_boinc_files(dest_dir, install_web_files, install_server_files):
         install_glob(srcdir('html/languages/translations/*.po'), dest('html/languages/translations/'))
 
     # copy Python stuff
-    install(srcdir('sched/start' ), dest('bin/start' ))    
+    install(srcdir('sched/start' ), dest('bin/start' ))
     force_symlink(dest('bin', 'start'), dest('bin', 'stop'))
     force_symlink(dest('bin', 'start'), dest('bin', 'status'))
     python_files = [
@@ -365,7 +365,7 @@ def install_boinc_files(dest_dir, install_web_files, install_server_files):
 
     content = '''
 # Generated by make_project
-import sys, os                                                                                                            
+import sys, os
 sys.path.insert(0, os.path.join('{dest_dir}', 'py'))
 '''.format(dest_dir=dest_dir)
     f = open(dest('bin', 'boinc_path_config.py'), "w")
@@ -412,8 +412,8 @@ sys.path.insert(0, os.path.join('{dest_dir}', 'py'))
             'script_assimilator',
             'script_validator',
             'show_shmem',
-            'single_job_assimilator', 
-            'size_regulator', 
+            'single_job_assimilator',
+            'size_regulator',
             'transitioner',
             'transitioner_catchup.php',
             'trickle_credit',
@@ -433,7 +433,6 @@ sys.path.insert(0, os.path.join('{dest_dir}', 'py'))
             'cancel_jobs',
             'create_work',
             'dbcheck_files_exist',
-            'db_query',
             'demo_query',
             'demo_submit',
             'dir_hier_move',
@@ -444,8 +443,8 @@ sys.path.insert(0, os.path.join('{dest_dir}', 'py'))
             'run_in_ops',
             'sign_executable',
             'stage_file',
+            'stage_file_native',
             'update_versions',
-            'watch_tcp',
             'xadd',
         ]
     for f in command:
@@ -526,7 +525,7 @@ class Project:
         for x in dirs:
             location = os.path.join(location, x)
         return location
-        
+
     def keydir(self, location):
             return os.path.join(self.config.config.key_dir, location)
 
@@ -596,7 +595,7 @@ class Project:
         content = '''
 <!-- <scheduler>{url}</scheduler> -->"
 <link rel=\"boinc_scheduler\" href=\"url"\">
-        '''.format(url=self.scheduler_url.strip())    
+        '''.format(url=self.scheduler_url.strip())
         f = open(self.dest('html/user', 'schedulers.txt'), 'w')
         f.write(content)
         f.close()
