@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2019 University of California
+// Copyright (C) 2023 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -35,7 +35,6 @@
 #include "util.h"
 #include "str_util.h"
 #include "synch.h"
-
 #include "credit.h"
 #include "hr.h"
 #include "sched_array.h"
@@ -53,12 +52,8 @@
 #include "sched_types.h"
 #include "sched_util.h"
 #include "sched_version.h"
-
 #include "sched_send.h"
-
-#ifdef _USING_FCGI_
-#include "boinc_fcgi.h"
-#endif
+#include "boinc_stdio.h"
 
 // if host sends us an impossible RAM size, use this instead
 //
@@ -135,7 +130,7 @@ const double MAX_REQ_SECS = (28*SECONDS_IN_DAY);
 void WORK_REQ::get_job_limits() {
     int ninstances[NPROC_TYPES];
     int i;
-    
+
     memset(ninstances, 0, sizeof(ninstances));
     int n;
     n = g_reply->host.p_ncpus;
@@ -348,20 +343,12 @@ static void get_reliability_and_trust() {
 double max_allowable_disk() {
     HOST host = g_request->host;
     GLOBAL_PREFS prefs = g_request->global_prefs;
-    double x1, x2, x3, x;
+    double x, x1=0, x2=0, x3;
 
     // defaults are from config.xml
     // if not there these are used:
-    // -default_max_used_gb= 100
-    // -default_max_used_pct = 50
-    // -default_min_free_gb = .001
+    // default_disk_min_free_gb = 1
     //
-    if (prefs.disk_max_used_gb == 0) {
-       prefs.disk_max_used_gb = config.default_disk_max_used_gb;
-    }
-    if (prefs.disk_max_used_pct == 0) {
-       prefs.disk_max_used_pct = config.default_disk_max_used_pct;
-    }
     if (prefs.disk_min_free_gb < config.default_disk_min_free_gb) {
        prefs.disk_min_free_gb = config.default_disk_min_free_gb;
     }
@@ -374,17 +361,32 @@ double max_allowable_disk() {
         // The post 4 oct 2005 case.
         // Compute the max allowable additional disk usage based on prefs
         //
-        x1 = prefs.disk_max_used_gb*GIGA - host.d_boinc_used_total;
-        x2 = host.d_total * prefs.disk_max_used_pct / 100.0
-            - host.d_boinc_used_total;
-        x3 = host.d_free - prefs.disk_min_free_gb*GIGA;      // may be negative
-        x = std::min(x1, std::min(x2, x3));
+        x3 = host.d_free - prefs.disk_min_free_gb*GIGA;
+            // may be negative
+        x = x3;
+        int which = 3;
+        if (prefs.disk_max_used_pct > 0) {
+            x2 = host.d_total * prefs.disk_max_used_pct / 100.0
+                - host.d_boinc_used_total;
+            if (x2 < x) {
+                x = x2;
+                which = 2;
+            }
+        }
+        if (prefs.disk_max_used_gb > 0) {
+            x1 = prefs.disk_max_used_gb*GIGA - host.d_boinc_used_total;
+            if (x1 < x) {
+                x = x1;
+                which = 1;
+            }
+        }
 
         // see which bound is the most stringent
+        // (for client notification in sched_locality.cpp)
         //
-        if (x==x1) {
+        if (which == 1) {
             g_reply->disk_limits.max_used = x;
-        } else if (x==x2) {
+        } else if (which == 2) {
             g_reply->disk_limits.max_frac = x;
         } else {
             g_reply->disk_limits.min_free = x;
@@ -1006,16 +1008,39 @@ int add_result_to_reply(
     }
     result.bav = *bavp;
     g_reply->insert_result(result);
+
+    // decrement the work requests (seconds and instances)
+    // based on the estimated duration of this job
+    // and how many instances it uses.
+    //
+    // If it's a GPU job, don't decrement the CPU requests,
+    // because the scheduling of GPU jobs is constrained by the # of GPUs
+    //
     if (g_wreq->rsc_spec_request) {
         int pt = bavp->host_usage.proc_type;
         if (pt == PROC_TYPE_CPU) {
-            g_wreq->req_secs[PROC_TYPE_CPU] -= est_dur;
+            double est_cpu_secs = est_dur*bavp->host_usage.avg_ncpus;
+            g_wreq->req_secs[PROC_TYPE_CPU] -= est_cpu_secs;
             g_wreq->req_instances[PROC_TYPE_CPU] -= bavp->host_usage.avg_ncpus;
+            if (config.debug_send_job) {
+                log_messages.printf(MSG_NORMAL,
+                    "[send_job] est_dur %f est_cpu_secs %f; new req_secs %f\n",
+                    est_dur, est_cpu_secs, g_wreq->req_secs[PROC_TYPE_CPU]
+                );
+            }
         } else {
-            g_wreq->req_secs[pt] -= est_dur;
+            double est_gpu_secs = est_dur*bavp->host_usage.gpu_usage;
+            g_wreq->req_secs[pt] -= est_gpu_secs;
             g_wreq->req_instances[pt] -= bavp->host_usage.gpu_usage;
+            if (config.debug_send_job) {
+                log_messages.printf(MSG_NORMAL,
+                    "[send_job] est_dur %f est_gpu_secs %f; new req_secs %f\n",
+                    est_dur, est_gpu_secs, g_wreq->req_secs[pt]
+                );
+            }
         }
     } else {
+        // extremely old clients don't send per-resource requests
         g_wreq->seconds_to_fill -= est_dur;
     }
     update_estimated_delay(*bavp, est_dur);
